==> WWW-GoKGS-0.01.tar.gz: WWW-GoKGS-0.01/t/data/TournEntrants/id-619-sort-s/expected.pl <==
{
  'entrants' => [
    {
      'name' => 'Zen19',
      'notes' => 'Winner',
      'position' => '1',
      'rank' => '4d',
      'score' => '6',
      'sodos' => '20',
      'sos' => '26',
      'standing' => undef
    },
    {
      'name' => 'pachi2',
      'notes' => '',
      'position' => '2',
      'rank' => '3d',
      'score' => '6',
      'sodos' => '19',
      'sos' => '24',
      'standing' => undef
    },
    {
      'name' => 'stv',
      'notes' => '',
      'position' => '3',
      'rank' => '-',
      'score' => '5',
      'sodos' => '16',
      'sos' => '27',
      'standing' => undef
    },
    {
      'name' => 'AyaMC',
      'notes' => '',
      'position' => '4',
      'rank' => '1d',
      'score' => '5',
      'sodos' => '14',
      'sos' => '26',
      'standing' => undef
    },
    {
      'name' => 'CzechBot',
      'notes' => '',
      'position' => '5',
      'rank' => '1k',
      'score' => '3',
      'sodos' => '7',
      'sos' => '25',
      'standing' => undef
    },
    {
      'name' => 'gomorra3',
      'notes' => '',
      'position' => '6',
      'rank' => '-',
      'score' => '3',
      'sodos' => '4',
      'sos' => '20',
      'standing' => undef
    },
    {
      'name' => 'SimpleBot',
      'notes' => '',
      'position' => '7',
      'rank' => '-',
      'score' => '2',
      'sodos' => '5',
      'sos' => '29',
      'standing' => undef
    },
    {
      'name' => 'Orego12',
      'notes' => '',
      'position' => '8',
      'rank' => '6k',
      'score' => '2',
      'sodos' => '5',
      'sos' => '26',
      'standing' => undef
    },
    {
      'name' => 'PueGo',
      'notes' => '',
      'position' => '9',
      'rank' => '-',
      'score' => '2',
      'sodos' => '4',
      'sos' => '23',
      'standing' => undef
    },
    {
      'name' => 'oakfoam',
      'notes' => '',
      'position' => '10',
      'rank' => '-',
      'score' => '2',
      'sodos' => '2',
      'sos' => '21',
      'standing' => undef
    },
    {
      'name' => 'WeakBot50k',
      'notes' => 'Quit before round 2',
      'position' => '11',
      'rank' => '21k',
      'score' => '0',
      'sodos' => '0',
      'sos' => '2',
      'standing' => undef
    }
  ],
  'links' => {
    'entrants' => [
      {
        'sort_by' => 'name',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournEntrants.jsp?sort=n&id=619')}, 'URI::http' )
      },
      {
        'sort_by' => 'result',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournEntrants.jsp?sort=s&id=619')}, 'URI::http' )
      }
    ],
    'rounds' => [
      {
        'end_time' => '2011-09-04T17:00Z',
        'round' => '1',
        'start_time' => '2011-09-04T16:00Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=619&round=1')}, 'URI::http' )
      },
      {
        'end_time' => '2011-09-04T18:00Z',
        'round' => '2',
        'start_time' => '2011-09-04T17:00Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=619&round=2')}, 'URI::http' )
      },
      {
        'end_time' => '2011-09-04T19:00Z',
        'round' => '3',
        'start_time' => '2011-09-04T18:00Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=619&round=3')}, 'URI::http' )
      },
      {
        'end_time' => '2011-09-04T20:00Z',
        'round' => '4',
        'start_time' => '2011-09-04T19:00Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=619&round=4')}, 'URI::http' )
      },
      {
        'end_time' => '2011-09-04T21:00Z',
        'round' => '5',
        'start_time' => '2011-09-04T20:00Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=619&round=5')}, 'URI::http' )
      },
      {
        'end_time' => '2011-09-04T22:00Z',
        'round' => '6',
        'start_time' => '2011-09-04T21:00Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=619&round=6')}, 'URI::http' )
      },
      {
        'end_time' => '2011-09-04T23:00Z',
        'round' => '7',
        'start_time' => '2011-09-04T22:00Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=619&round=7')}, 'URI::http' )
      }
    ]
  },
  'name' => 'September 2011 KGS bot tournament',
  'results' => {}
}

==> WWW-GoKGS-0.08.tar.gz: WWW-GoKGS-0.08/t/data/TournEntrants/id-619-sort-s/expected.pl <==
{
  'entrants' => [
    {
      'name' => 'Zen19',
      'notes' => 'Winner',
      'position' => 1,
      'rank' => '4d',
      'score' => 6,
      'sodos' => 20,
      'sos' => 26
    },
    {
      'name' => 'pachi2',
      'notes' => '',
      'position' => 2,
      'rank' => '3d',
      'score' => 6,
      'sodos' => 19,
      'sos' => 24
    },
    {
      'name' => 'stv',
      'notes' => '',
      'position' => 3,
      'rank' => '-',
      'score' => 5,
      'sodos' => 16,
      'sos' => 27
    },
    {
      'name' => 'AyaMC',
      'notes' => '',
      'position' => 4,
      'rank' => '1d',
      'score' => 5,
      'sodos' => 14,
      'sos' => 26
    },
    {
      'name' => 'CzechBot',
      'notes' => '',
      'position' => 5,
      'rank' => '1k',
      'score' => 3,
      'sodos' => 7,
      'sos' => 25
    },
    {
      'name' => 'gomorra3',
      'notes' => '',
      'position' => 6,
      'rank' => '-',
      'score' => 3,
      'sodos' => 4,
      'sos' => 20
    },
    {
      'name' => 'SimpleBot',
      'notes' => '',
      'position' => 7,
      'rank' => '-',
      'score' => 2,
      'sodos' => 5,
      'sos' => 29
    },
    {
      'name' => 'Orego12',
      'notes' => '',
      'position' => 8,
      'rank' => '6k',
      'score' => 2,
      'sodos' => 5,
      'sos' => 26
    },
    {
      'name' => 'PueGo',
      'notes' => '',
      'position' => 9,
      'rank' => '-',
      'score' => 2,
      'sodos' => 4,
      'sos' => 23
    },
    {
      'name' => 'oakfoam',
      'notes' => '',
      'position' => 10,
      'rank' => '-',
      'score' => 2,
      'sodos' => 2,
      'sos' => 21
    },
    {
      'name' => 'WeakBot50k',
      'notes' => 'Quit before round 2',
      'position' => 11,
      'rank' => '21k',
      'score' => 0,
      'sodos' => 0,
      'sos' => 2
    }
  ],
  'links' => {
    'entrants' => [
      {
        'sort_by' => 'name',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournEntrants.jsp?sort=n&id=619')}, 'URI::http' )
      },
      {
        'sort_by' => 'result',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournEntrants.jsp?sort=s&id=619')}, 'URI::http' )
      }
    ],
    'rounds' => [
      {
        'end_time' => '2011-09-04T17:00Z',
        'round' => 1,
        'start_time' => '2011-09-04T16:00Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=619&round=1')}, 'URI::http' )
      },
      {
        'end_time' => '2011-09-04T18:00Z',
        'round' => 2,
        'start_time' => '2011-09-04T17:00Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=619&round=2')}, 'URI::http' )
      },
      {
        'end_time' => '2011-09-04T19:00Z',
        'round' => 3,
        'start_time' => '2011-09-04T18:00Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=619&round=3')}, 'URI::http' )
      },
      {
        'end_time' => '2011-09-04T20:00Z',
        'round' => 4,
        'start_time' => '2011-09-04T19:00Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=619&round=4')}, 'URI::http' )
      },
      {
        'end_time' => '2011-09-04T21:00Z',
        'round' => 5,
        'start_time' => '2011-09-04T20:00Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=619&round=5')}, 'URI::http' )
      },
      {
        'end_time' => '2011-09-04T22:00Z',
        'round' => 6,
        'start_time' => '2011-09-04T21:00Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=619&round=6')}, 'URI::http' )
      },
      {
        'end_time' => '2011-09-04T23:00Z',
        'round' => 7,
        'start_time' => '2011-09-04T22:00Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=619&round=7')}, 'URI::http' )
      }
    ]
  },
  'name' => 'September 2011 KGS bot tournament'
}
